using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Input.Touch;
using Microsoft.Xna.Framework.Media;

namespace WindowsPhoneGameMango
{
    /// <summary>
    /// This is the main type for your game
    /// </summary>
    public class Game : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        SpriteBatch spriteBatch;

        GamePadState prevGamePadState;
        GamePadState currGamePadState;

        GestureSample gesture;

        SpriteFont font;

        string gamepadText = "No button pressed yet"; // salva le info relative al gamepad
        string gestureTypeText = "Touch not available yet"; // salva le info relative al tipo di gesture
        string touchPositionText = "Touch not available yet"; // salva le info relative alla posizione del touch

        public Game()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";

            // Frame rate is 30 fps by default for Windows Phone.
            TargetElapsedTime = TimeSpan.FromTicks(333333);

            // Extend battery life under lock.
            InactiveSleepTime = TimeSpan.FromSeconds(1);

            // Optional. Uncomment if you prefer the portrait orientation
            //graphics.SupportedOrientations = DisplayOrientation.Portrait;
            //graphics.PreferredBackBufferWidth = 480;
            //graphics.PreferredBackBufferHeight = 800;

            TouchPanel.EnabledGestures = GestureType.Tap | GestureType.DoubleTap | GestureType.Flick;
        }

        /// <summary>
        /// Allows the game to perform any initialization it needs to before starting to run.
        /// This is where it can query for any required services and load any non-graphic
        /// related content.  Calling base.Initialize will enumerate through any components
        /// and initialize them as well.
        /// </summary>
        protected override void Initialize()
        {
            // TODO: Add your initialization logic here

            base.Initialize();
        }

        /// <summary>
        /// LoadContent will be called once per game and is the place to load
        /// all of your content.
        /// </summary>
        protected override void LoadContent()
        {
            // Create a new SpriteBatch, which can be used to draw textures.
            spriteBatch = new SpriteBatch(GraphicsDevice);

            font = Content.Load<SpriteFont>("font");
        }

        /// <summary>
        /// UnloadContent will be called once per game and is the place to unload
        /// all content.
        /// </summary>
        protected override void UnloadContent()
        {
            // TODO: Unload any non ContentManager content here
        }

        /// <summary>
        /// Allows the game to run logic such as updating the world,
        /// checking for collisions, gathering input, and playing audio.
        /// </summary>
        /// <param name="gameTime">Provides a snapshot of timing values.</param>
        protected override void Update(GameTime gameTime)
        {
            // Passa l'ultimo stato registrato a prevGamePadState
            prevGamePadState = currGamePadState;

            // Legge il nuovo stato
            currGamePadState = GamePad.GetState(PlayerIndex.One);

            // Controlla se  stato premuto (e rilasciato) il bottone Back
            if (prevGamePadState.IsButtonDown(Buttons.Back) && currGamePadState.IsButtonUp(Buttons.Back))
                gamepadText = ("Last button pressed: Back");

            // Controlla che ci sia un nuovo gesture non processato
            while (TouchPanel.IsGestureAvailable)
            {
                // legge il touchPanel
                gesture = TouchPanel.ReadGesture();

                // memorizza il tipo di gesture
                gestureTypeText = "Last gesture type: " + gesture.GestureType.ToString();

                // se si tratta di un tap o di un doppio tap, salva la posizione del punto di contatto
                if (gesture.GestureType == GestureType.Tap || gesture.GestureType == GestureType.DoubleTap)
                    touchPositionText = string.Format("X: {0} - Y : {1}", gesture.Position.X, gesture.Position.Y);

                    // se  un flick, mostra il delta
                else if (gesture.GestureType == GestureType.Flick)
                    touchPositionText = string.Format("Delta X: {0} - Delta Y: {1}", gesture.Delta.X, gesture.Delta.Y);
            }

            base.Update(gameTime);
        }

        /// <summary>
        /// This is called when the game should draw itself.
        /// </summary>
        /// <param name="gameTime">Provides a snapshot of timing values.</param>
        protected override void Draw(GameTime gameTime)
        {
            GraphicsDevice.Clear(Color.CornflowerBlue);

            spriteBatch.Begin();

            // GamePad Text
            spriteBatch.DrawString(font, gamepadText, new Vector2(10, 20), Color.White);
            // Touchpad Text
            spriteBatch.DrawString(font, gestureTypeText, new Vector2(10, 60), Color.White);
            spriteBatch.DrawString(font, touchPositionText, new Vector2(10, 100), Color.White);

            spriteBatch.End();

            base.Draw(gameTime);
        }
    }
}
